\\ Подключение библиотек
#include "LedControl.h"
#include "DHT.h"
#define DHTPIN 2
#define DHTTYPE DHT22
#include <Wire.h>
#include <BMP085.h>

\\ Инициализация
BMP085 dps = BMP085();
DHT dht(DHTPIN, DHTTYPE);
LedControl lc = LedControl(12, 11, 10, 1);

int ResPin = A0; // Пин с переменным резистором
int ResVal = 0;  // Значение переменного резистора

static unsigned long TimeMeas ; // Время измерения
static unsigned long TimeDisp ; // Время обновления вывода
static unsigned long TimeRes ;  // Время измерения положения переменного резистора
static unsigned long TimeOn ;   // Время проверки необходимости включения излучателей


static float Hum = 0;           // Измеренная влажность
static float HumSet = 0;        // Установленная влажность
static float Temp = 0;          // Измеренная температура
static long Pres = 0;           // Измеренное атмосферное давление


void setup() {
  // Начальные установки
  pinMode(4, OUTPUT);
  dht.begin();
  Wire.begin();
  lc.shutdown(0, false);
  lc.clearDisplay(0);
  lc.setIntensity(0, 13);
  dps.init(MODE_ULTRA_HIGHRES, 25000, true);

}

/*   --- Вывод 2-х символов на LED --- */
void print2dig (int dig, int pl1, int pl2, bool dot) {
  lc.setDigit(0, pl2, dig % 10, false);
  lc.setDigit(0, pl1, (dig % 100 - dig % 10) / 10, false);
}

/*   --- Вывод 3-х символов на LED с точкой полсе 2-го символа --- */
void print3dig (int dig, int pl1, int pl2, int pl3, bool dot) {
  lc.setDigit(0, pl3, dig % 10, false);
  lc.setDigit(0, pl2, (dig % 100 - dig % 10) / 10, dot);
  lc.setDigit(0, pl1, (dig % 1000 - dig % 100) / 100, false);
}


void loop() {

  /*   --- Измерение параметров каждые 2 сек --- */
  if (millis() >= (TimeMeas + 2000)) {
    Temp = dht.readTemperature() * 10;
    Hum   = dht.readHumidity() * 10;
    dps.getPressure(&Pres);
    Pres = Pres / 133.322 - 26;

    TimeMeas = millis();
  }

  /*   --- Циклический вывод измерений каждые 5 сек --- */
  if (millis() >= (TimeDisp + 500)) {
    unsigned long i = millis() / 5000;
    if (i % 3 == 0) {
      digitalWrite(0, 255); // крсный
      digitalWrite(1, 0);
      digitalWrite(3, 0);
      print3dig(Temp, 0, 1, 2, true);
    }
    if (i % 3 == 1) {
      digitalWrite(0, 0);
      digitalWrite(1, 255);  // Желтый
      digitalWrite(3, 0);
      print3dig(Pres, 0, 1, 2, false);
    }
    if (i % 3 == 2) {
      digitalWrite(0, 0);
      digitalWrite(1, 0);
      digitalWrite(3, 255);   // Зеленый
      print3dig(Hum, 0, 1, 2, true);
    }
    TimeDisp = millis();
  }

  /*   --- Чтение положения переменного резистора --- */
  if (millis() >= (TimeRes + 200)) {
    ResVal = 0;
    for (int w = 0; w < 10; w++) {          // читаем 10 раз
      ResVal = ResVal + analogRead(ResPin);
    }
    ResVal = ResVal / 10;                   // усредняем
    ResVal = map(ResVal, 0, 1023, 0, 99);
    HumSet = ResVal;                        // устанавливаем настройку

    print2dig(ResVal, 3, 4, false);         // выводим настройку на LED
    TimeRes = millis();
  }

  /*   --- Включение излучателей если измеренная влажность меньше установленной --- */
  if (millis() >= (TimeOn + 500)) {
    if ((Hum / 10) < HumSet) {
      digitalWrite(4, HIGH);
    }
    else
    {
      digitalWrite(4, LOW);
    }
    TimeOn = millis();
  }


}
